---
title: <span class="badge object-type-scalar"></span> RadiansPerSecond
---
# <span class="badge object-type-scalar"></span> RadiansPerSecond

Rotational Speed: Radians per second (rad/s)

## Definition

```python
# Rotational Speed: Radians per second (rad/s)
RadiansPerSecond: typing.Literal["rotrads"] = "rotrads"
```
